pulp-cookbook Changelog
=======================

Version 0.0.3a1
---------------

Released on Dec 19, 2018

- Adapt to pulpcore-plugin 0.1.0b15


Version 0.0.2a2
---------------

Released on Sep 14, 2018

- Initial version with sync and publish support (suitable for berkshelf).

